package com.mortals.xhx.module.certificate.model;

import java.lang.reflect.Type;
import java.util.List;
import java.util.ArrayList;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.parser.DefaultJSONParser;
import com.alibaba.fastjson.parser.JSONToken;
import com.alibaba.fastjson.parser.deserializer.ObjectDeserializer;
import com.fasterxml.jackson.annotation.JsonInclude;
import lombok.Data;
import org.springframework.util.ObjectUtils;

import java.io.Serializable;
import java.util.stream.Collectors;
/**
* 行业目录前端映射树结构实体类
*
* @author zxfei
* @date 2024-08-08
*/
@Data
public class CertificateIndustryTreeSelect  implements Serializable {
    private static final long serialVersionUID = 1L;

    /**
    * 节点ID
    */
    private Long id;

    /**
     * 父节点ID
     */
    private Long parentId;

    /**
    * 节点名称
    */
    private String label;

    /**
    * 子节点
    */
    @JsonInclude(JsonInclude.Include.NON_EMPTY)
    private List<CertificateIndustryTreeSelect> children;

    public CertificateIndustryTreeSelect() {

    }

    public CertificateIndustryTreeSelect(CertificateIndustryEntity entity) {
        this.id = entity.getId();
        this.parentId = entity.getParentId();
        this.label = entity.getIndustryName();
        if(!ObjectUtils.isEmpty(entity.getChildren())){
            this.children = entity.getChildren().stream().map(CertificateIndustryTreeSelect::new).collect(Collectors.toList());
        }
    }

    // 反序列化器
    public  class Deserializer implements ObjectDeserializer {
        @Override
        public CertificateIndustryTreeSelect deserialze(DefaultJSONParser parser, Type type, Object fieldName) {
            CertificateIndustryTreeSelect node = new CertificateIndustryTreeSelect();
            JSONObject jsonObject = parser.parseObject();
            node.setId(jsonObject.getLong("id"));
            node.setLabel(jsonObject.getString("label"));
            JSONArray jsonArray = jsonObject.getJSONArray("children");
            List<CertificateIndustryTreeSelect> children = new ArrayList<>();
            if(!ObjectUtils.isEmpty(jsonArray)){
                for (int i = 0; i < jsonArray.size(); i++) {
                    CertificateIndustryTreeSelect child = JSON.parseObject(jsonArray.getJSONObject(i).toJSONString(), CertificateIndustryTreeSelect.class);
                    children.add(child);
                }
            }
            node.setChildren(children);
            return node;
        }

        @Override
        public int getFastMatchToken() {
            return JSONToken.LBRACE;
        }
    }


    public static void main(String[] args) {
        String json="{\n" +
                "    \"children\": [\n" +
                "        {\n" +
                "            \"children\": [\n" +
                "                {\n" +
                "                    \"id\": 10,\n" +
                "                    \"label\": \"小餐馆\"\n" +
                "                },\n" +
                "                {\n" +
                "                    \"id\": 11,\n" +
                "                    \"label\": \"奶茶店\"\n" +
                "                },\n" +
                "                {\n" +
                "                    \"id\": 14,\n" +
                "                    \"label\": \"咖啡店\"\n" +
                "                }\n" +
                "            ],\n" +
                "            \"id\": 1,\n" +
                "            \"label\": \"餐饮类\"\n" +
                "        },\n" +
                "        {\n" +
                "            \"children\": [\n" +
                "                {\n" +
                "                    \"id\": 16,\n" +
                "                    \"label\": \"超市\"\n" +
                "                },\n" +
                "                {\n" +
                "                    \"id\": 17,\n" +
                "                    \"label\": \"便利店\"\n" +
                "                }\n" +
                "            ],\n" +
                "            \"id\": 15,\n" +
                "            \"label\": \"购物类\"\n" +
                "        },\n" +
                "        {\n" +
                "            \"children\": [\n" +
                "                {\n" +
                "                    \"id\": 19,\n" +
                "                    \"label\": \"茶楼\"\n" +
                "                },\n" +
                "                {\n" +
                "                    \"id\": 20,\n" +
                "                    \"label\": \"酒吧\"\n" +
                "                },\n" +
                "                {\n" +
                "                    \"id\": 21,\n" +
                "                    \"label\": \"游艺厅\"\n" +
                "                },\n" +
                "                {\n" +
                "                    \"id\": 22,\n" +
                "                    \"label\": \"电玩城\"\n" +
                "                },\n" +
                "                {\n" +
                "                    \"id\": 23,\n" +
                "                    \"label\": \"KTV\"\n" +
                "                },\n" +
                "                {\n" +
                "                    \"id\": 24,\n" +
                "                    \"label\": \"洗浴场所\"\n" +
                "                },\n" +
                "                {\n" +
                "                    \"id\": 25,\n" +
                "                    \"label\": \"网吧\"\n" +
                "                },\n" +
                "                {\n" +
                "                    \"id\": 26,\n" +
                "                    \"label\": \"游乐场\"\n" +
                "                },\n" +
                "                {\n" +
                "                    \"id\": 27,\n" +
                "                    \"label\": \"电影院\"\n" +
                "                }\n" +
                "            ],\n" +
                "            \"id\": 18,\n" +
                "            \"label\": \"娱乐类\"\n" +
                "        }\n" +
                "    ],\n" +
                "    \"id\": -1,\n" +
                "    \"label\": \"全部行业\"\n" +
                "}";


        CertificateIndustryTreeSelect certificateIndustryTreeSelect = JSONObject.parseObject(json, CertificateIndustryTreeSelect.class);


        System.out.println(JSONObject.toJSONString(certificateIndustryTreeSelect));

    }

}