package com.mortals.xhx.module.certificate.web;

import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.Context;
import com.mortals.framework.web.BaseCRUDJsonBodyMappingController;
import com.mortals.xhx.base.system.param.service.ParamService;
import com.mortals.xhx.common.code.StatusEnum;
import com.mortals.xhx.module.certificate.model.CertificateChildEntity;
import com.mortals.xhx.module.certificate.model.CertificateChildQuery;
import com.mortals.xhx.module.certificate.model.CertificateDocumentEntity;
import com.mortals.xhx.module.certificate.service.CertificateChildService;
import com.mortals.xhx.module.certificate.service.CertificateDocumentService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.ObjectUtils;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * 子证配置
 *
 * @author zxfei
 * @date 2024-07-27
 */
@RestController
@RequestMapping("certificate/document")
public class CertificateDocumentController extends BaseCRUDJsonBodyMappingController<CertificateDocumentService, CertificateDocumentEntity, Long> {

    @Autowired
    private CertificateChildService certificateChildService;


    public CertificateDocumentController() {
        super.setModuleDesc("子证配置");
    }

    @Override
    protected void init(Map<String, Object> model, Context context) {
        this.addDict(model, "status", StatusEnum.getEnumMap());
        super.init(model, context);
    }


    @Override
    protected void doListBefore(CertificateDocumentEntity query, Map<String, Object> model, Context context) throws AppException {
        if (!ObjectUtils.isEmpty(query.getCatalogId())) {
            List<Long> documentIdList = certificateChildService.find(new CertificateChildQuery().catalogId(query.getCatalogId())).stream()
                    .map(CertificateChildEntity::getDocumentId).collect(Collectors.toList());
            if (!ObjectUtils.isEmpty(documentIdList)) {
                query.setIdList(documentIdList);
            } else {
                query.setIdList(Arrays.asList(-1L));
            }
        }
        super.doListBefore(query, model, context);
    }

    @Override
    protected void doListAfter(CertificateDocumentEntity query, List<CertificateDocumentEntity> list, Context context) throws AppException {
        list.forEach(item -> {
            item.setFormContent("");
        });

        super.doListAfter(query, list, context);
    }
}